# Segments

These functions

![Breaking neurons into linear segments. This is the same toy skeleton used in the examples below.](../_static/segments.png)

## Generate Segments

::: navis_fastcore.generate_segments

## Segment Coordinates

::: navis_fastcore.segment_coords